# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2012 Steffen Kockel s.kockel@groovecubes.de
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import optparse

import gettext
from gettext import gettext as _
gettext.textdomain('arduino-scope')

import gtk

from arduino_scope import ArduinoScopeWindow
from arduino_scope.PreferencesArduinoScopeDialog import PreferencesArduinoScopeDialog

from arduino_scope_lib import set_up_logging, preferences, get_version
from arduino_scope.helper import check_serial_connection



def parse_options():
    """Support for command line options"""
    parser = optparse.OptionParser(version="%%prog %s" % get_version())
    parser.add_option(
        "-v", "--verbose", action="count", dest="verbose",
        help=_("Show debug messages (-vv debugs arduino_scope_lib also)"))
    (options, args) = parser.parse_args()

    set_up_logging(options)

def main():
    'constructor for your class instances'
    parse_options()

    default_preferences = {
    'serial_port': '/dev/ttyACM0',
    'baudrate':'230400',
    'samplerate':'62500',
    'canvas_color':'1,1,1',
    'grid_color':'0,0,0',
    }

    preferences.update(default_preferences)
    # user's stored preferences are used for 2nd and subsequent sessions
    preferences.db_connect()
    preferences.load()
    # display preferences dialog if connection check fails.
    if not check_serial_connection():
        PreferencesArduinoScopeDialog().run()
        if not check_serial_connection():
            return

    # Run the application.    
    window = ArduinoScopeWindow.ArduinoScopeWindow()
    window.show()
    gtk.main()
    
    preferences.save()
